Crate obel_platform

Platform agnostic support

Modules

collectionsalloc
Collection types and utilities for working with collections in a platform-agnostic way.
hash
Provides replacements for std::hash items using foldhash.
string
Platform-agnostic impls to string items
sync
Provides various synchronization alternatives to language primitives.
time
Provides Instant for all platforms.
utils
General utilities for first-party obel engine crates.
vec
Platform-agnostic impls to vec items

Macros

run_once
A macro that ensures the given expression is executed exactly once per call site.